@@ -145,6 +145,22 @@ bj_card_load_pixmaps (GtkWidget* app, GdkCardDeckOptions deck_options)
   gchar *buffer;
 
   card_deck = (GObject*) gdk_card_deck_new (app->window, deck_options);
+  if (card_deck == NULL)
+    {
+      GtkWidget *error_dialog;
+      error_dialog = gtk_message_dialog_new (GTK_WINDOW (app),
+                                             GTK_DIALOG_MODAL,
+                                             GTK_MESSAGE_ERROR,
+                                             GTK_BUTTONS_CLOSE,
+                                             "<b>%s</b>\n\n%s",
+                                             _("Could not load the card deck images."),
+                                             _("Blackjack will now exit."));
+      gtk_dialog_set_has_separator (GTK_DIALOG (error_dialog), FALSE);
+      gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (error_dialog)->label), TRUE);
+      gtk_dialog_run (GTK_DIALOG (error_dialog));
+      gtk_widget_destroy (error_dialog);
+      exit (1);
+    }
   mask = gdk_card_deck_mask (GDK_CARD_DECK (card_deck)); 
 
   buffer = g_build_filename ("blackjack", "chip-100.png", NULL);
