@@ -70,9 +70,8 @@ help_about_callback ()
 {
   GdkPixbuf *pixbuf = NULL;
   const gchar *authors[] = {
-	  N_("Main game:"),
-	  "William Jon McCann (mccann@jhu.edu)",
-	  "Eric Farmer (erfarmer201@comcast.net)",
+	  "William Jon McCann <mccann@jhu.edu>",
+	  "Eric Farmer <erfarmer201@comcast.net>",
 	  NULL
   };
 
@@ -102,9 +101,8 @@ help_about_callback ()
   }
   about = gnome_about_new ( _("Blackjack"), VERSION,
                             /* copyright notice */
-                            "Copyright \xc2\xa9 2003 William Jon McCann "
-	                    "<mccann@jhu.edu>, Eric Farmer "
-		            "<erfarmer201@comcast.net>",
+                            "Copyright \xc2\xa9 2003 "
+                            "William Jon McCann, Eric Farmer",
                             _("Blackjack provides a casino-style "
                               "blackjack card game."),
                             (const char **)authors,
