@@ -147,6 +147,20 @@ zero_board (void)
 		}
 }
 
+/* Avoid a race condition where a redraw is attempted
+ * between the window being destroyed and the destroy
+ * event being sent. */
+static gint
+delete_cb (GtkWidget * widget, gpointer data)
+{
+	if (main_id) g_source_remove (main_id);
+	if (erase_id) g_source_remove (erase_id);
+	if (dummy_id) g_source_remove (dummy_id);
+	if (restart_id) g_source_remove (restart_id);
+
+	return FALSE;
+}
+
 static void
 quit_cb (GtkWidget *widget, gpointer data)
 {
@@ -589,8 +603,10 @@ setup_window (void)
 	window = gnome_app_new ("gnibbles", "GNOME Nibbles");
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
 	gtk_widget_realize (window);
-	g_signal_connect (G_OBJECT (window), "delete_event",
+	g_signal_connect (G_OBJECT (window), "destroy",
 			G_CALLBACK (quit_cb), NULL);
+	g_signal_connect (G_OBJECT (window), "delete_event",
+			G_CALLBACK (delete_cb), NULL);
 
 	drawing_area = gtk_drawing_area_new ();
 
@@ -637,34 +653,25 @@ static void
 gconf_key_change_cb (GConfClient *client, guint cnxn_id,
 		     GConfEntry *entry, gpointer user_data)
 {
-	end_game (1);
-	gnibbles_properties_destroy (properties);
-	properties = gnibbles_properties_new ();
+	gnibbles_properties_update (properties);
 }
 
 static void
 load_properties ()
 {
-	gint i;
-	gchar *buffer;
+	GConfClient * client;
 
 	properties = gnibbles_properties_new ();
+	client = gconf_client_get_default ();
 
 	/* maybe this should to into properties.c */
-        gconf_client_add_dir (gconf_client_get_default (),
+        gconf_client_add_dir (client,
                               KEY_DIR,
                               GCONF_CLIENT_PRELOAD_RECURSIVE,
                               NULL);
-	gconf_client_notify_add (gconf_client_get_default (),
+	gconf_client_notify_add (client,
 				 KEY_PREFERENCES_DIR,
 				 gconf_key_change_cb, NULL, NULL, NULL);
-	for (i = 0; i < NUMWORMS; i++) {
-		buffer = g_strdup_printf (KEY_WORM_DIR, i);
-		gconf_client_notify_add (gconf_client_get_default (),
-					 buffer,
-					 gconf_key_change_cb, NULL, NULL, NULL);
-		g_free (buffer);
-	}
 }
 
 static void
