@@ -44,14 +44,15 @@ update_score_cell(GtkWidget *treeview, gint row, gint col, int val)
 
         g_assert(treeview != NULL);
 
-        if (val < 0)
-                return;
-
         model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
         gtk_tree_model_iter_nth_child(model, &iter, NULL, row);
-        buf = g_strdup_printf("%i", val);
-        gtk_list_store_set(GTK_LIST_STORE(model), &iter, col, buf, -1);
-        g_free(buf);
+        if (val < 0)
+                gtk_list_store_set(GTK_LIST_STORE(model), &iter, col, "", -1);
+        else {
+                buf = g_strdup_printf("%i", val);
+                gtk_list_store_set(GTK_LIST_STORE(model), &iter, col, buf, -1);
+                g_free(buf);
+        }
 }
 
 static void
@@ -129,7 +130,7 @@ row_activated_cb(GtkTreeView *treeview, GtkTreePath *path,
         case (R_LTOTAL):
                 break;
         default:
-                /* Adjust for Uppe Total / Bonus entries */
+                /* Adjust for Upper Total / Bonus entries */
                 if (row >= NUM_UPPER)
                         row -= 3;
 
