@@ -23,6 +23,7 @@
 #include <gconf/gconf-client.h>
 #include <games-gconf.h>
 #include <games-frame.h>
+#include <games-files.h>
 
 /* Define a sensible alternative to ngettext if we don't have it. Note that
  * this is only sensible in the context of same-gnome. */
@@ -42,7 +43,6 @@
 #define KEY_DIR "/apps/same-gnome"
 #define KEY_TILESET "/apps/same-gnome/tileset"
 #define KEY_SCORE "/apps/same-gnome/score"
-#define KEY_NSTONES "/apps/same-gnome/nstones"
 #define KEY_FIELD "/apps/same-gnome/field"
 
 static GtkWidget *pref_dialog, *scorew;
@@ -139,6 +139,9 @@ flood_fill (int x, int y, int color)
 {
 	int c = 0;
 	
+	if (!color)
+		return c;
+	
 	if (field [x][y].color != color)
 		return c;
 	
@@ -193,8 +196,6 @@ mark_balls (int x, int y)
 
 	untag_all ();
 	disable_timeout ();
-	if (!field [x][y].color)
-		return;
 	
 	tagged_count = flood_fill (x, y, field [x][y].color);
 	
@@ -555,46 +556,40 @@ set_selection (GtkTreeSelection *selection, gpointer data)
 	gconf_client_set_string (conf_client, KEY_TILESET, filename, NULL);
 }
 
+static void fill_list_foreach (gchar * string, GtkListStore * list)
+{
+        GtkTreeIter iter;
+	gchar *name;
+	gchar *suffix;
+	
+	/* We strip any trailing suffix, any -sync suffix
+	 * and convert '_' to ' '. This is brutal code. */
+	name = g_strdup (string);
+	suffix = g_strrstr (name,".");
+	if (suffix) *suffix = '\0';
+	suffix = g_strrstr (name,"-sync");
+	if (suffix) *suffix = '\0';
+	suffix = name;
+	while (*suffix) {
+		if (*suffix == '_') *suffix = ' ';
+		suffix++;
+	}
+	
+	gtk_list_store_append (list, &iter);
+	gtk_list_store_set (list, &iter, 0, name, 1, g_strdup (string), -1);
+} 
+
 static void
 fill_list (GtkListStore *list)
 {
-        GDir * dir;
-        gchar * filename;
-        GtkTreeIter iter;
+	GamesFileList * filelist;
 	
-	dir = g_dir_open (PIXMAPDIR, 0, NULL);
-
-	if (!dir)
-		return;
+	filelist = games_file_list_new_images (PIXMAPDIR, NULL);
+	games_file_list_transform_basename (filelist);
 	
-	while ((filename = g_strdup (g_dir_read_name (dir))) != NULL) {
-		gchar *name;
-                gchar *suffix;
-                gchar *path = NULL;
-                path = g_build_filename (PIXMAPDIR, filename, NULL);
-                if (!g_file_test (path, G_FILE_TEST_IS_REGULAR)) {
-                        g_free (filename);
-			g_free (path);
-                        continue;
-                }
+	games_file_list_for_each (filelist, (GFunc) fill_list_foreach, list);
 
-                /* We strip any trailing suffix, any -sync suffix
-                 * and convert '_' to ' '. This is brutal code. */
-                name = g_strdup (filename);
-                suffix = g_strrstr (name,".");
-                if (suffix) *suffix = '\0';
-                suffix = g_strrstr (name,"-sync");
-                if (suffix) *suffix = '\0';
-                suffix = name;
-                while (*suffix) {
-                        if (*suffix == '_') *suffix = ' ';
-                        suffix++;
-                }
-                
-                gtk_list_store_append (list, &iter);
-                gtk_list_store_set (list, &iter, 0, name, 1, filename, -1);
-	}
-	g_dir_close (dir);
+	g_object_unref (filelist);
 }
 
 static void
@@ -825,7 +820,6 @@ save_state (GnomeClient *client,
 	int i;  
 	
 	gconf_client_set_int (conf_client, KEY_SCORE, score, NULL);
-	gconf_client_set_int (conf_client, KEY_NSTONES, sync_stones ? 1 : nstones, NULL);
 	
 	buf= g_malloc (STONE_COLS*STONE_LINES+1);
 
@@ -846,9 +840,13 @@ restart (void)
 	gchar *buf;
 	struct ball *f = (struct ball*) field;
 	int i;
-	
+
+	/* It's too late to fix this for 2.4, but setting the score
+	 * from something the player can fiddle with is *not* a
+	 * good idea. */
 	score = gconf_client_get_int (conf_client, KEY_SCORE, NULL);
-	nstones = gconf_client_get_int (conf_client, KEY_NSTONES, NULL);
+	if (score < 0)
+		score = 0;
 	
 	buf = gconf_client_get_string (conf_client, KEY_FIELD, NULL);
 
@@ -856,8 +854,12 @@ restart (void)
 		for (i= 0; i < (STONE_COLS*STONE_LINES); i++) 
 		{
 			f[i].color= buf[i] - 'a';
+			if (f[i].color < 1)
+				f[i].color = 1;
+			if (f[i].color > ncolors)
+				f[i].color = ncolors;
 			f[i].tag  = 0;
-			f[i].frame= nstones ? (rand () % nstones) : 0;
+			f[i].frame= rand () % nstones;
 		}
 		g_free (buf);
 	}
@@ -947,6 +949,9 @@ main (int argc, char *argv [])
 			(conf_client, KEY_TILESET, NULL);
 	}
 
+	if (!fname)
+		fname = g_strdup ("stones.png");
+
 	create_same_board (fname);
 
 	update_score_state ();
